@@ -1,8 +1,8 @@
+# coding: utf-8
+
 from cms.plugins.text.models import AbstractText
 from django.db.models import CharField
 from django.utils.translation import ugettext_lazy as _
-from django.template.defaultfilters import truncatewords_html
-from django.utils.html import strip_tags
 
 
 class Footnote(AbstractText):
@@ -12,6 +12,3 @@ class Footnote(AbstractText):
     class Meta:
         verbose_name = _('Footnote')
         verbose_name_plural = _('Footnotes')
-
-    def __unicode__(self):
-        return strip_tags(truncatewords_html(self.body, 5))
